@@ -1,5 +1,5 @@
 <div class="header"><?php MenuFormlet::show() ?></div>
 
-<h2>ڡʹ</h2>
+<h1>ڡ</h1>
 <?php AllPagesFormlet::show() ?>
 <p></p>
