@@ -1,9 +1,15 @@
 <div class="header"><?php MenuFormlet::show() ?></div>
 
+<h1>桼</h1>
+
 <h2>ɽ</h2>
 
 <?php FormletEditFormlet::show() ?>
 
 <h2>ơޤ</h2>
 
-<?php ThemeChooseFormlet::show() ?>
\ No newline at end of file
+<?php ThemeChooseFormlet::show() ?>
+
+<h2>ѥɤѹ</h2>
+
+<?php ChangePasswordFormlet::show() ?>
