@@ -1,12 +1,21 @@
 <html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=EUC-JP">
-<title><?php echo htmlspecialchars($title) ?> [ SocieWiki ]</title>
+<title><?php echo htmlspecialchars($title) ?> [ <?php echo htmlspecialchars(SITE_NAME) ?> ]</title>
 <link rel="shortcut icon" href="/favicon.ico">
 <?php StylesheetFormlet::show() ?>
+<script language="javascript">
+function focusing()
+{
+  if (location.hash == "#QueueList") {
+    var input = document.getElementById("queueInput");
+    input.focus();
+  }
+}
+</script>
 </head>
 
-<body>
+<body onLoad="focusing()">
 <?php include $module; ?>
 <div class="footer" align="right">
 <p>
